@@ -1,7 +1,11 @@
+// This Source Code Form is subject to the terms of the Mozilla Public
+// License, v. 2.0. If a copy of the MPL was not distributed with this
+// file, You can obtain one at https://mozilla.org/MPL/2.0/.
+
 use std::fmt;
 
-use ra_ap_hir as hir;
-use ra_ap_ide_db::{defs::Definition, RootDatabase};
+use ra_ap_hir::{self as hir, HasVisibility};
+use ra_ap_ide_db::RootDatabase;
 
 #[derive(Clone, PartialEq, Debug)]
 pub enum NodeVisibility {
@@ -14,8 +18,7 @@ pub enum NodeVisibility {
 
 impl<'a> NodeVisibility {
     pub fn new(hir: hir::ModuleDef, db: &RootDatabase) -> Self {
-        let definition = Definition::ModuleDef(hir);
-        let visibility = definition.visibility(db);
+        let visibility = hir.visibility(db);
 
         let parent_module = match hir.module(db) {
             Some(module) => module,
@@ -26,7 +29,7 @@ impl<'a> NodeVisibility {
         let krate_module = parent_module.krate().root_module(db);
 
         match visibility {
-            Some(hir::Visibility::Module(visibility_module_id)) => {
+            hir::Visibility::Module(visibility_module_id) => {
                 let visibility_module = hir::Module::from(visibility_module_id);
                 if visibility_module == krate_module {
                     Self::Crate
@@ -42,9 +45,7 @@ impl<'a> NodeVisibility {
                     Self::Module(path)
                 }
             }
-            Some(hir::Visibility::Public) => Self::Public,
-            // The crate's top-most root module doesn't have an explicit visibility:
-            None => Self::Public,
+            hir::Visibility::Public => Self::Public,
         }
     }
 }
